version 9
capture log close
log using "roster_dates.smcl", replace
*
* age_dob.do
* Author: Ian Timaeus
* Date: 3 October 2004

* Calculates age_dob using dates of birth if available and the 1998 
* age if the 2004 data are missing/impossible
*
clear
*
* MERGE 1998 AND 2004 ROSTERS
*
use "roster 1998 less 2 clusters only.dta", clear
sort hhid pcode
save "roster 1998 less 2 clusters only.dta", replace

use temp_roster, clear
gen long hhid = int(hhid2004/100)
sort hhid pcode

merge hhid pcode using "roster 1998 less 2 clusters only.dta", nokeep
tab _merge 
*
* RECALCULATE AGE FROM DATES OF INTERVIEW AND BIRTH (if known)
*
gen long newdob = mdy(dob_month,dob_day,dob_year)
replace newdob = mdy(dob_month,15,dob_year) if dob_day<1 
replace newdob = mdy(6,30,dob_year) if dob_month<1 
replace newdob = . if dob_year<1

gen int age_dob = age
replace age_dob = int((a7d-newdob)/365.25) if a7d~=. & newdob~=. & ///
	(dob_month>0 | age<0)
*
* PERSON CANNOT BE < 5 IF WAS ALREADY BORN IN 1998 WAVE
*
replace age_dob = age if age_dob<5 & pcode<100 & age_dob<age
*
* USE 1998 DATA IF age_dob IS MISSING OR IMPOSSIBLY YOUNG
*
replace age_dob = age98+int((a7d-date98)/365.25) if lived==1 & ///
	pcode<100 & age98>=0 & a7d~=. & age_dob<6

label var age_dob "Age using birth date/2004 age/1998 age"
label values age_dob a5
tab age_dob if (pcode>100 | lived==1) & age_dob<0, miss
drop newdob
move age_dob a1

drop _merge clustnum date98 supcode hhid-relhd98
drop a1-loans_b activito qual_o spouse_o father_o mother_o
save roster2004, replace

erase "temp_roster.dta"

log close
